@@ -1,7 +1,7 @@
 
 from typing import Optional
 from MSApi.ObjectMS import ObjectMS, check_init
-from MSApi import Employee
+from MSApi.Employee import Employee
 
 
 class Project(ObjectMS):
@@ -18,7 +18,7 @@ class Project(ObjectMS):
 
     @check_init
     def get_owner(self) -> Optional[Employee]:
-        return Employee(self._json.get('owner'))
+        return self._get_optional_object('owner', Employee)
 
     @check_init
     def get_shared(self) -> bool:
